@@ -138,6 +138,14 @@ proj_info_extract = function(path_to_raster,
 #'                              crs_bbox = 4326,
 #'                              URL = 'https://api.planet.com/basemaps/v1/mosaics',
 #'                              verbose = TRUE)
+#'
+#' #........................................
+#' # WKT of the area covered from NICFI data
+#' #........................................
+#'
+#' nicfi_aoi = sf::st_as_sfc(mosaic_files$dtbl_mosaic$mosaic_wkt[1], crs = 4326)
+#' cat(sf::st_as_text(nicfi_aoi))
+#'
 #' }
 
 
@@ -156,6 +164,10 @@ nicfi_mosaics = function(planet_api_key,
   link = content_response$`_links`$`_self`
   mosaics = content_response$mosaics
 
+  valid_nicfi_image_types = unique(unlist(lapply(mosaics, function(x) unlist(x$item_types))))
+  user_has_img_types = paste(sapply(valid_nicfi_image_types, function(x) glue::glue("'{x}'")), collapse = ', ')
+  if (!all(c("REOrthoTile", "PSScene4Band") %in% valid_nicfi_image_types)) stop(glue::glue("Valid 'NICFI' Image types are 'REOrthoTile' and 'PSScene4Band', whereas you have {user_has_img_types}! Please follow the suggested registration in https://www.planet.com/nicfi/"), call. = F)
+
   mosaics = lapply(mosaics, function(x) {                                                 # extract the information of all mosaics (including the id's)
 
     nam_trunc = gsub('planet_medres_normalized_analytic_', '', x$name)
@@ -168,6 +180,7 @@ nicfi_mosaics = function(planet_api_key,
                         xmax = bbx[3],
                         ymax = bbx[4]),
                       crs = sf::st_crs(crs_bbox))
+
     plg = sf::st_as_sfc(plg, crs = crs_bbox)
     plg = sf::st_as_text(plg)
 
@@ -489,6 +502,8 @@ aria2c_download_paths = function(mosaic_output,
 #'
 #' https://aria2.github.io/manual/en/html/aria2c.html#cmdoption-m
 #'
+#' https://aria2.github.io/manual/en/html/aria2c.html#exit-status
+#'
 #' @export
 #'
 #' @examples
